package Exception::Multistate::NotFound;
$Exception::Multistate::NotFound::VERSION = '0.010';
use base qw(Exception::Multistate);

1;
